function [yypred] = getVForecast_nant(qahead,nvar,nshocks,TTT,RRR,DD,ZZ,QQ,z,...
                                  ind_r,ind_r_sh,zerobound,bdd_int_rate,nant,sflag,nantpol,ant_sh,rtarget,varargin)
                              
%% Check inputs      

switch nargin
    case 18
        tflag = 0;
        df = [];
    case 20
        tflag = varargin{1}; 
        df = varargin{2};    
    otherwise 
        fprintf('Incorrect number of inputs for getForecast.m');
end

if bdd_int_rate && ( isempty(ind_r) || isempty(ind_r_sh) )
    error('accounting for 0.25 interest rate bound: interest rate not in observables or monetary policy shock not in shocks')
end


%% Compute Policy Shocks
lefthand = nan(nantpol,1);
Mmat = nan(nantpol,nantpol);

if nantpol>1
    allr_ind = [ind_r_sh,ant_sh:ant_sh+nantpol-2];
else
    allr_ind = [ind_r_sh];
end

TT0 = eye(size(TTT));
TT1 = TTT;


if nantpol>0
    for j=1:nantpol;
        lefthand(j) = rtarget(j) - DD(ind_r) - ZZ(ind_r,:)*TT1*z;
        Mmat(j,:) = ZZ(ind_r,:)*TT0*RRR(:,allr_ind);
        TT0 = TTT*TT0;
        TT1 = TTT*TT1;
    end
end

polshocks = Mmat\lefthand;

%Shocks_ = zeros(qahead,nshocks);

%Shocks_(1,allr_ind) = polshocks;

%% Initialize output

yypred = zeros(qahead,nvar);

%% Draw shocks for forecasting
if tflag 
    htil_draw = chi2rnd(repmat(df,1,qahead))./repmat(df,1,qahead);
    Shocks = randn(qahead,nshocks)*sqrt(QQ)./sqrt(htil_draw');
else
    Shocks = repmat(sqrt(diag(QQ)'),qahead,1).*randn(qahead,nshocks);
    Shocks(:,ant_sh:ant_sh+nant-1) = zeros(qahead,nant);  % LOOK A THIS!!!! allr_ind
end

%TURN SHOCKS OFF
if sflag
    Shocks=zeros(size(Shocks));
end

%Shocks=zeros(size(Shocks));

if nantpol>0
    Shocks(1,allr_ind) = polshocks;
end

%Shocks = Shocks + Shocks_;


%% Calculate forecast 
% Applying state transition equation and measurement equation 
% S_t = TTT*S_(t-1) + RRR*eps_t
% y_t = ZZ*S_t + DD

for t = 1:qahead;
    z_test = TTT*z+RRR*Shocks(t,:)';
    yypred(t,:) = (DD+ZZ*z_test)';

    % This changes the monetary policy shock to account for the 0.25 interest rate bound    
    % For zero bound forecast we need forecasts with bounded interest rate on and off
    
    if yypred(t,ind_r)<0.25/4 && bdd_int_rate
        Shocks(t,ind_r_sh) = 0;
        Shocks(t,ind_r_sh) = (0.25/4 - DD(ind_r) - ZZ(ind_r,:)*(TTT*z + RRR*Shocks(t,:)'))/(ZZ(ind_r,:)*RRR(:,ind_r_sh));
        z = TTT*z+RRR*Shocks(t,:)';
        yypred(t,:) = (DD+ZZ*z)';
        if yypred(t,ind_r) < 0.249/4
            error('0.25 interest rate bound procedure not working')
        end
    else
        z = z_test;
    end
end